==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/insights/kotlin/inputs/MetricDimensionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.inputs

import com.pulumi.azurenative.insights.inputs.MetricDimensionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Specifies a metric dimension.
 * @property name Name of the dimension.
 * @property operator the dimension operator. Only 'Include' and 'Exclude' are supported
 * @property values list of dimension values.
 */
public data class MetricDimensionArgs(
    public val name: Output<String>,
    public val `operator`: Output<String>,
    public val values: Output<List<String>>,
) : ConvertibleToJava<com.pulumi.azurenative.insights.inputs.MetricDimensionArgs> {
    override fun toJava(): com.pulumi.azurenative.insights.inputs.MetricDimensionArgs =
        com.pulumi.azurenative.insights.inputs.MetricDimensionArgs.builder()
            .name(name.applyValue({ args0 -> args0 }))
            .`operator`(`operator`.applyValue({ args0 -> args0 }))
            .values(values.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [MetricDimensionArgs].
 */
@PulumiTagMarker
public class MetricDimensionArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var `operator`: Output<String>? = null

    private var values: Output<List<String>>? = null

    /**
     * @param value Name of the dimension.
     */
    @JvmName("npvyafbcxqtqvkxd")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value the dimension operator. Only 'Include' and 'Exclude' are supported
     */
    @JvmName("xxrllqkguqsnnjxe")
    public suspend fun `operator`(`value`: Output<String>) {
        this.`operator` = value
    }

    /**
     * @param value list of dimension values.
     */
    @JvmName("mhqcxywsjwjkkbhx")
    public suspend fun values(`value`: Output<List<String>>) {
        this.values = value
    }

    @JvmName("sgygnvmdmdmatvqc")
    public suspend fun values(vararg values: Output<String>) {
        this.values = Output.all(values.asList())
    }

    /**
     * @param values list of dimension values.
     */
    @JvmName("wtuofebuebnumkxe")
    public suspend fun values(values: List<Output<String>>) {
        this.values = Output.all(values)
    }

    /**
     * @param value Name of the dimension.
     */
    @JvmName("wlakweluaccjwpcy")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value the dimension operator. Only 'Include' and 'Exclude' are supported
     */
    @JvmName("mgdxxtoyknivyohn")
    public suspend fun `operator`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`operator` = mapped
    }

    /**
     * @param value list of dimension values.
     */
    @JvmName("xoihbqliarthcgoo")
    public suspend fun values(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.values = mapped
    }

    /**
     * @param values list of dimension values.
     */
    @JvmName("tcsplthsjxromwfo")
    public suspend fun values(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.values = mapped
    }

    internal fun build(): MetricDimensionArgs = MetricDimensionArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        `operator` = `operator` ?: throw PulumiNullFieldException("operator"),
        values = values ?: throw PulumiNullFieldException("values"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/insights/kotlin/inputs/MetricDimensionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.inputs

import com.pulumi.azurenative.insights.inputs.MetricDimensionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Specifies a metric dimension.
 * @property name Name of the dimension.
 * @property operator the dimension operator. Only 'Include' and 'Exclude' are supported
 * @property values list of dimension values.
 */
public data class MetricDimensionArgs(
    public val name: Output<String>,
    public val `operator`: Output<String>,
    public val values: Output<List<String>>,
) : ConvertibleToJava<com.pulumi.azurenative.insights.inputs.MetricDimensionArgs> {
    override fun toJava(): com.pulumi.azurenative.insights.inputs.MetricDimensionArgs =
        com.pulumi.azurenative.insights.inputs.MetricDimensionArgs.builder()
            .name(name.applyValue({ args0 -> args0 }))
            .`operator`(`operator`.applyValue({ args0 -> args0 }))
            .values(values.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [MetricDimensionArgs].
 */
@PulumiTagMarker
public class MetricDimensionArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var `operator`: Output<String>? = null

    private var values: Output<List<String>>? = null

    /**
     * @param value Name of the dimension.
     */
    @JvmName("tjowuqiuhwrdwwrh")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value the dimension operator. Only 'Include' and 'Exclude' are supported
     */
    @JvmName("dhiesoswpmldhdfh")
    public suspend fun `operator`(`value`: Output<String>) {
        this.`operator` = value
    }

    /**
     * @param value list of dimension values.
     */
    @JvmName("ekvjpiatlsgjotsy")
    public suspend fun values(`value`: Output<List<String>>) {
        this.values = value
    }

    @JvmName("vjxjlswgyglpmsct")
    public suspend fun values(vararg values: Output<String>) {
        this.values = Output.all(values.asList())
    }

    /**
     * @param values list of dimension values.
     */
    @JvmName("hugncstvwiimjomo")
    public suspend fun values(values: List<Output<String>>) {
        this.values = Output.all(values)
    }

    /**
     * @param value Name of the dimension.
     */
    @JvmName("yemfccbqtlfoqwwr")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value the dimension operator. Only 'Include' and 'Exclude' are supported
     */
    @JvmName("iuboyxdytjhhqypx")
    public suspend fun `operator`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`operator` = mapped
    }

    /**
     * @param value list of dimension values.
     */
    @JvmName("aovelsemnrarbtnu")
    public suspend fun values(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.values = mapped
    }

    /**
     * @param values list of dimension values.
     */
    @JvmName("tspvsvdmaothnxvc")
    public suspend fun values(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.values = mapped
    }

    internal fun build(): MetricDimensionArgs = MetricDimensionArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        `operator` = `operator` ?: throw PulumiNullFieldException("operator"),
        values = values ?: throw PulumiNullFieldException("values"),
    )
}
